<?php
// Register the shortcode
add_shortcode('o3nhtmlcopier', 'o3n_hc_shortcode');

/*
 * This is the shortcode callback function that returns an html element from given url.
*
* By setting the shortcode's parameters you can specify url to get the element from and place of the element. Element is an html tag.
*
* @param Array $attr An array containing the parameters of the shortcode. url is the url of the page that we want to get an element from.  tagname is the tag name of the html element we want to get. count is the place # of the html element in the page. (for example if you want the 8th table in the page you need to set count 8) striplinks if set true removes any links from copied content. striphtml if set true removes all the html tags from copied content. allowedtags if set defines the tags to be allowed when striphtml is true. showsource if set to 1 shows a link to source url. sourcelabel is the text to show as link.
*/
function o3n_hc_shortcode( $attr ) {

	$o3n_hc_options = get_option('o3n_htmlcopier_options');
	
	// Merge incoming $attr with saved options
	$attr = wp_parse_args( $attr, $o3n_hc_options );
	
	// Defaults for other parameters
	$defaults = array(
			'count' => 1,
			'striplinks' => false,
			'striphtml' => false,
			'sourcelabel' => 'Source >>'
	);
	
	// Merge altered (by saved options) incoming $attr with defaults
	$o3n_hc_current_options = wp_parse_args( $attr, $defaults );

	// allowed tags parameter comes as comma seperated tagnames. Change it into comma seperated markups
	if ( isset( $attr['allowedtags']) && $o3n_hc_current_options['striphtml']) {
		$o3n_hc_allowedtags = '';
		// make an array out of comma seperated tags and format as a string of tags
		$o3n_hc_tagarray = explode(',', $attr['allowedtags']);
		foreach ($o3n_hc_tagarray as $o3n_hc_tag) {
			$o3n_hc_allowedtags = $o3n_hc_allowedtags.'<'.trim($o3n_hc_tag).'>';
		}
	}
	else {
		$o3n_hc_allowedtags = '';
	}

	// get content from the page
	$o3n_hc_pagetogetcontent = file_get_contents($o3n_hc_current_options['url']);
	
	// Find the nth occurance of tagname
	for ($i2=1; $i2<=$o3n_hc_current_options['count']; $i2++)
	{
		// remove what is before opening tag
		$o3n_hc_pagetogetcontent = stristr($o3n_hc_pagetogetcontent, '<'.$o3n_hc_current_options['tagname']);
		// remove tagname so you don't find it again next time
		$o3n_hc_pagetogetcontent = substr($o3n_hc_pagetogetcontent, strlen($o3n_hc_current_options['tagname']) + 1);
	}
	
	$o3n_hc_positionofcontent = stripos($o3n_hc_pagetogetcontent, '</'.$o3n_hc_current_options['tagname'].'>');
	$o3n_hc_contentfrompage = substr($o3n_hc_pagetogetcontent, 0, $o3n_hc_positionofcontent);
	
	if ($o3n_hc_current_options['striplinks']) {
		$o3n_hc_contentfrompage = preg_replace("/<a [^>]+\>/i", " ", $o3n_hc_contentfrompage);
	}

	if ($o3n_hc_current_options['striphtml']) {
		$o3n_hc_contentfrompage = strip_tags($o3n_hc_contentfrompage, $o3n_hc_allowedtags);
	}

	if ($o3n_hc_current_options['showsource'] == 1) {
		$o3n_hc_sourcelink = "<a id='o3nsourcelink' href=".$o3n_hc_current_options['url']." target='_blank'>".$o3n_hc_current_options['sourcelabel']."</a>";
	}
	else {
		$o3n_hc_sourcelink = "";
	}

	return '<'.$o3n_hc_current_options['tagname'].' '.$o3n_hc_contentfrompage.' '.$o3n_hc_sourcelink.' </'.$o3n_hc_current_options['tagname'].'>';
}
?>